/****************************************************************************
** QgsCopyrightLabelPlugin meta object code from reading C++ file 'plugin.h'
**
** Created: Fri Nov 4 14:26:23 2005
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "plugin.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *QgsCopyrightLabelPlugin::className() const
{
    return "QgsCopyrightLabelPlugin";
}

QMetaObject *QgsCopyrightLabelPlugin::metaObj = 0;
static QMetaObjectCleanUp cleanUp_QgsCopyrightLabelPlugin( "QgsCopyrightLabelPlugin", &QgsCopyrightLabelPlugin::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString QgsCopyrightLabelPlugin::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsCopyrightLabelPlugin", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString QgsCopyrightLabelPlugin::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsCopyrightLabelPlugin", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* QgsCopyrightLabelPlugin::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QObject::staticMetaObject();
    static const QUMethod slot_0 = {"initGui", 0, 0 };
    static const QUMethod slot_1 = {"projectRead", 0, 0 };
    static const QUMethod slot_2 = {"run", 0, 0 };
    static const QUParameter param_slot_3[] = {
	{ 0, &static_QUType_ptr, "QPainter", QUParameter::In }
    };
    static const QUMethod slot_3 = {"renderLabel", 1, param_slot_3 };
    static const QUMethod slot_4 = {"refreshCanvas", 0, 0 };
    static const QUMethod slot_5 = {"unload", 0, 0 };
    static const QUMethod slot_6 = {"help", 0, 0 };
    static const QUParameter param_slot_7[] = {
	{ 0, &static_QUType_varptr, "\x05", QUParameter::In }
    };
    static const QUMethod slot_7 = {"setFont", 1, param_slot_7 };
    static const QUParameter param_slot_8[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod slot_8 = {"setLabel", 1, param_slot_8 };
    static const QUParameter param_slot_9[] = {
	{ 0, &static_QUType_varptr, "\x0a", QUParameter::In }
    };
    static const QUMethod slot_9 = {"setColor", 1, param_slot_9 };
    static const QUParameter param_slot_10[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod slot_10 = {"setPlacement", 1, param_slot_10 };
    static const QUParameter param_slot_11[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_11 = {"setEnable", 1, param_slot_11 };
    static const QMetaData slot_tbl[] = {
	{ "initGui()", &slot_0, QMetaData::Public },
	{ "projectRead()", &slot_1, QMetaData::Public },
	{ "run()", &slot_2, QMetaData::Public },
	{ "renderLabel(QPainter*)", &slot_3, QMetaData::Public },
	{ "refreshCanvas()", &slot_4, QMetaData::Public },
	{ "unload()", &slot_5, QMetaData::Public },
	{ "help()", &slot_6, QMetaData::Public },
	{ "setFont(QFont)", &slot_7, QMetaData::Public },
	{ "setLabel(QString)", &slot_8, QMetaData::Public },
	{ "setColor(QColor)", &slot_9, QMetaData::Public },
	{ "setPlacement(QString)", &slot_10, QMetaData::Public },
	{ "setEnable(bool)", &slot_11, QMetaData::Public }
    };
    metaObj = QMetaObject::new_metaobject(
	"QgsCopyrightLabelPlugin", parentObject,
	slot_tbl, 12,
	0, 0,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_QgsCopyrightLabelPlugin.setMetaObject( metaObj );
    return metaObj;
}

void* QgsCopyrightLabelPlugin::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "QgsCopyrightLabelPlugin" ) )
	return this;
    if ( !qstrcmp( clname, "QgisPlugin" ) )
	return (QgisPlugin*)this;
    return QObject::qt_cast( clname );
}

bool QgsCopyrightLabelPlugin::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: initGui(); break;
    case 1: projectRead(); break;
    case 2: run(); break;
    case 3: renderLabel((QPainter*)static_QUType_ptr.get(_o+1)); break;
    case 4: refreshCanvas(); break;
    case 5: unload(); break;
    case 6: help(); break;
    case 7: setFont((QFont)(*((QFont*)static_QUType_ptr.get(_o+1)))); break;
    case 8: setLabel((QString)static_QUType_QString.get(_o+1)); break;
    case 9: setColor((QColor)(*((QColor*)static_QUType_ptr.get(_o+1)))); break;
    case 10: setPlacement((QString)static_QUType_QString.get(_o+1)); break;
    case 11: setEnable((bool)static_QUType_bool.get(_o+1)); break;
    default:
	return QObject::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool QgsCopyrightLabelPlugin::qt_emit( int _id, QUObject* _o )
{
    return QObject::qt_emit(_id,_o);
}
#ifndef QT_NO_PROPERTIES

bool QgsCopyrightLabelPlugin::qt_property( int id, int f, QVariant* v)
{
    return QObject::qt_property( id, f, v);
}

bool QgsCopyrightLabelPlugin::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
